@@ -246,9 +246,6 @@ void Part::activeViewChanged(SessionController *controller)
     disconnect(controller->view(), displaySignal, this, partSlot);
     connect(controller->view(), displaySignal, this, partSlot);
 
-    // set the current session's search bar
-    controller->setSearchBar(_viewManager->searchBar());
-
     _pluggedController = controller;
 }
 
