@@ -57,6 +57,9 @@ ViewContainer::ViewContainer(NavigationPosition position, QObject *parent) :
     QObject(parent),
     _navigationVisibility(AlwaysShowNavigation),
     _navigationPosition(position),
+    _views(QList<QWidget *>()),
+    _navigation(QHash<QWidget *, ViewProperties *>()),
+    _features(nullptr),
     _searchBar(nullptr)
 {
 }
@@ -273,8 +276,16 @@ QList<QWidget *> ViewContainer::widgetsForItem(ViewProperties *item) const
 TabbedViewContainer::TabbedViewContainer(NavigationPosition position,
                                          ViewManager *connectedViewManager, QObject *parent) :
     ViewContainer(position, parent),
+    _tabBar(nullptr),
+    _stackWidget(nullptr),
+    _containerWidget(nullptr),
     _connectedViewManager(connectedViewManager),
-    _contextMenuTabIndex(0)
+    _layout(nullptr),
+    _tabBarLayout(nullptr),
+    _newTabButton(nullptr),
+    _closeTabButton(nullptr),
+    _contextMenuTabIndex(0),
+    _contextPopupMenu(nullptr)
 {
     _containerWidget = new QWidget;
     _stackWidget = new QStackedWidget();
@@ -321,7 +332,8 @@ TabbedViewContainer::TabbedViewContainer(NavigationPosition position,
     _contextPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("edit-rename")),
                                  i18nc("@action:inmenu", "&Rename Tab..."), this,
                                  SLOT(tabContextMenuRenameTab()));
-    _contextPopupMenu->actions().last()->setObjectName(QStringLiteral("edit-rename"));
+    const auto contextPopupMenuActions = _contextPopupMenu->actions();
+    contextPopupMenuActions.last()->setObjectName(QStringLiteral("edit-rename"));
 
     _contextPopupMenu->addSeparator();
 
@@ -530,7 +542,7 @@ void TabbedViewContainer::startTabDrag(int index)
     // start dragging
     const Qt::DropAction action = drag->exec();
 
-    if ((drag != nullptr) && (drag->target() != nullptr)) {
+    if ((!drag.isNull()) && (drag->target() != nullptr)) {
         switch (action) {
         case Qt::MoveAction:
             // The MoveAction indicates the widget has been successfully
@@ -639,7 +651,7 @@ void TabbedViewContainer::openTabContextMenu(const QPoint &point)
         }
 
         // Disable tab rename
-        for (auto *action : _contextPopupMenu->actions()) {
+        for (auto &action : _contextPopupMenu->actions()) {
             if (action->objectName() == QStringLiteral("edit-rename")) {
                 action->setEnabled(!sessionController->isReadOnly());
                 break;
@@ -748,7 +760,7 @@ void TabbedViewContainer::addViewWidget(QWidget *view, int index)
 
 void TabbedViewContainer::removeViewWidget(QWidget *view)
 {
-    if (_stackWidget == nullptr) {
+    if (_stackWidget.isNull()) {
         return;
     }
     _stackWidget->removeWidget(view);
@@ -818,52 +830,3 @@ ViewManager *TabbedViewContainer::connectedViewManager()
 {
     return _connectedViewManager;
 }
-
-StackedViewContainer::StackedViewContainer(QObject *parent) :
-    ViewContainer(NavigationPositionTop, parent)
-{
-    _containerWidget = new QWidget;
-    auto layout = new QVBoxLayout(_containerWidget);
-
-    _stackWidget = new QStackedWidget(_containerWidget);
-
-    searchBar()->setParent(_containerWidget);
-    layout->addWidget(searchBar());
-    layout->addWidget(_stackWidget);
-    layout->setContentsMargins(0, 0, 0, 0);
-}
-
-StackedViewContainer::~StackedViewContainer()
-{
-    if (!_containerWidget.isNull()) {
-        _containerWidget->deleteLater();
-    }
-}
-
-QWidget *StackedViewContainer::containerWidget() const
-{
-    return _containerWidget;
-}
-
-QWidget *StackedViewContainer::activeView() const
-{
-    return _stackWidget->currentWidget();
-}
-
-void StackedViewContainer::setActiveView(QWidget *view)
-{
-    _stackWidget->setCurrentWidget(view);
-}
-
-void StackedViewContainer::addViewWidget(QWidget *view, int)
-{
-    _stackWidget->addWidget(view);
-}
-
-void StackedViewContainer::removeViewWidget(QWidget *view)
-{
-    if (_stackWidget == nullptr) {
-        return;
-    }
-    _stackWidget->removeWidget(view);
-}
