@@ -42,12 +42,13 @@ class QKeyEvent;
 #define MODE_Mouse1003       (MODES_SCREEN+6)   // Use all motion mouse tracking
 #define MODE_Mouse1005       (MODES_SCREEN+7)   // Xterm-style extended coordinates
 #define MODE_Mouse1006       (MODES_SCREEN+8)   // 2nd Xterm-style extended coordinates
-#define MODE_Mouse1015       (MODES_SCREEN+9)   // Urxvt-style extended coordinates
-#define MODE_Ansi            (MODES_SCREEN+10)   // Use US Ascii for character sets G0-G3 (DECANM)
-#define MODE_132Columns      (MODES_SCREEN+11)  // 80 <-> 132 column mode switch (DECCOLM)
-#define MODE_Allow132Columns (MODES_SCREEN+12)  // Allow DECCOLM mode
-#define MODE_BracketedPaste  (MODES_SCREEN+13)  // Xterm-style bracketed paste mode
-#define MODE_total           (MODES_SCREEN+14)
+#define MODE_Mouse1007       (MODES_SCREEN+9)   // XTerm Alternate Scroll mode; also check AlternateScrolling profile property
+#define MODE_Mouse1015       (MODES_SCREEN+10)   // Urxvt-style extended coordinates
+#define MODE_Ansi            (MODES_SCREEN+11)   // Use US Ascii for character sets G0-G3 (DECANM)
+#define MODE_132Columns      (MODES_SCREEN+12)  // 80 <-> 132 column mode switch (DECCOLM)
+#define MODE_Allow132Columns (MODES_SCREEN+13)  // Allow DECCOLM mode
+#define MODE_BracketedPaste  (MODES_SCREEN+14)  // Xterm-style bracketed paste mode
+#define MODE_total           (MODES_SCREEN+15)
 
 namespace Konsole {
 extern unsigned short vt100_graphics[32];
@@ -102,9 +103,10 @@ protected:
     void receiveChar(int cc) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
-    //causes changeTitle() to be emitted for each (int,QString) pair in pendingTitleUpdates
-    //used to buffer multiple title updates
-    void updateTitle();
+    // Causes sessionAttributeChanged() to be emitted for each (int,QString)
+    // pair in _pendingSessionAttributesUpdates.
+    // Used to buffer multiple attribute updates in the current session
+    void updateSessionAttributes();
 
 private:
     unsigned short applyCharset(unsigned short c);
@@ -149,8 +151,7 @@ private:
     void reportDecodingError();
 
     void processToken(int code, int p, int q);
-    void processWindowAttributeRequest();
-    void requestWindowAttribute(int);
+    void processSessionAttributeRequest();
 
     void reportTerminalType();
     void reportSecondaryAttributes();
@@ -180,13 +181,12 @@ private:
     TerminalState _currentModes;
     TerminalState _savedModes;
 
-    //hash table and timer for buffering calls to the session instance
-    //to update the name of the session
-    //or window title.
-    //these calls occur when certain escape sequences are seen in the
-    //output from the terminal
-    QHash<int, QString> _pendingTitleUpdates;
-    QTimer *_titleUpdateTimer;
+    // Hash table and timer for buffering calls to update certain session
+    // attributes (e.g. the name of the session, window title).
+    // These calls occur when certain escape sequences are detected in the
+    // output from the terminal. See Emulation::sessionAttributeChanged()
+    QHash<int, QString> _pendingSessionAttributesUpdates;
+    QTimer *_sessionAttributesUpdateTimer;
 
     bool _reportFocusEvents;
 };
