@@ -147,11 +147,66 @@ void CharacterColorTest::testColorSpaceSystem()
     const QColor result = charColor.color(DefaultColorTable);
 
     QCOMPARE(result, expected);
+}
 
-    //CharacterColor charColor(COLOR_SPACE_SYSTEM, 5);
-    //const QColor result = charColor.color(DefaultColorTable);
-    //const QColor expected = DefaultColorTable[7].color;
-    //QCOMPARE(result, expected);
+void CharacterColorTest::testColorSpaceRGB_data()
+{
+    QTest::addColumn<int>("colorValue");
+    QTest::addColumn<QColor>("expected");
+
+    // Pick colors to test or test all if needed
+    for (const int i : {0, 1, 64, 127, 128, 215, 255}) {
+        const QString name = QString::fromLatin1("color %1").arg(i);
+        QTest::newRow(qPrintable(name)) << i << QColor(i >> 16, i >> 8, i);
+    }
+}
+
+void CharacterColorTest::testColorSpaceRGB()
+{
+    QFETCH(int, colorValue);
+    QFETCH(QColor, expected);
+
+    CharacterColor charColor(COLOR_SPACE_RGB, colorValue);
+    const QColor result = charColor.color(DefaultColorTable);
+
+    QCOMPARE(result, expected);
+}
+void CharacterColorTest::testColor256_data()
+{
+    QTest::addColumn<int>("colorValue");
+    QTest::addColumn<QColor>("expected");
+
+    // This might be overkill
+    for (int i = 0; i < 8; ++i) {
+        const QString name = QString::fromLatin1("color256 color %1").arg(i);
+        QTest::newRow(qPrintable(name)) << i << DefaultColorTable[i + 2];
+    }
+    for (int i = 8; i < 16; ++i) {
+        const QString name = QString::fromLatin1("color256 color %1").arg(i);
+        QTest::newRow(qPrintable(name)) << i << DefaultColorTable[i + 2 + 10 - 8];
+    }
+    for (int i = 16; i < 232; ++i) {
+        const QString name = QString::fromLatin1("color256 color %1").arg(i);
+        const auto u = i - 16;
+        const auto color = QColor(((u / 36) % 6) ? (40 * ((u / 36) % 6) + 55) : 0,
+                      ((u / 6) % 6) ? (40 * ((u / 6) % 6) + 55) : 0,
+                      ((u / 1) % 6) ? (40 * ((u / 1) % 6) + 55) : 0);
+        QTest::newRow(qPrintable(name)) << i << color;
+    }
+    for (int i = 232; i < 256; ++i) {
+        const QString name = QString::fromLatin1("color256 color %1").arg(i);
+        const auto gray = (i - 232) * 10 + 8;
+        QTest::newRow(qPrintable(name)) << i << QColor(gray, gray, gray);
+    }
+}
+
+void CharacterColorTest::testColor256()
+{
+    QFETCH(int, colorValue);
+    QFETCH(QColor, expected);
+
+    const QColor result = color256(colorValue, DefaultColorTable);
+    QCOMPARE(result, expected);
 }
 
 QTEST_GUILESS_MAIN(CharacterColorTest)
